@@ -8,8 +8,6 @@
 
 """Helper functions for tests."""
 
-from __future__ import absolute_import, print_function
-
 from flask import url_for
 
 
@@ -18,10 +16,11 @@ def sign_up(app, client, email=None, password=None):
     with app.test_request_context():
         register_url = url_for('security.register')
 
-    client.post(register_url, data=dict(
+    res = client.post(register_url, data=dict(
         email=email or app.config['TEST_USER_EMAIL'],
         password=password or app.config['TEST_USER_PASSWORD'],
     ), environ_base={'REMOTE_ADDR': '127.0.0.1'})
+    assert res.status_code == 302  # redirect after signedup
 
 
 def login(app, client, email=None, password=None):
@@ -29,7 +28,8 @@ def login(app, client, email=None, password=None):
     with app.test_request_context():
         login_url = url_for('security.login')
 
-    client.post(login_url, data=dict(
+    res = client.post(login_url, data=dict(
         email=email or app.config['TEST_USER_EMAIL'],
         password=password or app.config['TEST_USER_PASSWORD'],
     ))
+    assert res.status_code == 302  # redirect after login
